# Generated by Django 2.1.7 on 2019-04-25 09:22

import django.db.models.deletion
from django.db import migrations, models

import katka.fields


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0015_update_pipeline_statuses_fix'),
    ]

    operations = [
        migrations.CreateModel(
            name='ApplicationMetadata',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('created_username', katka.fields.AutoUsernameField(max_length=50)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('modified_username', katka.fields.AutoUsernameField(max_length=50)),
                ('deleted', models.BooleanField(default=False)),
                ('key', models.CharField(max_length=50)),
                ('value', models.CharField(max_length=200)),
                ('application', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='katka.Application')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='applicationmetadata',
            unique_together={('application', 'key')},
        ),
    ]
