# Generated by Django 2.1.5 on 2019-02-12 02:12

import django.db.models.deletion
from django.db import migrations, models

import encrypted_model_fields.fields
import katka.fields


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0003_credential_and_unique_slugs'),
    ]

    operations = [
        migrations.CreateModel(
            name='CredentialSecret',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('created_username', katka.fields.AutoUsernameField(max_length=50)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('modified_username', katka.fields.AutoUsernameField(max_length=50)),
                ('status', models.CharField(choices=[('active', 'active'), ('inactive', 'inactive')], default='active', max_length=50)),
                ('key', models.CharField(max_length=50)),
                ('value', encrypted_model_fields.fields.EncryptedCharField()),
                ('credential', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='katka.Credential')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='credentialsecret',
            unique_together={('credential', 'key')},
        ),
    ]
